@@ -2,7 +2,7 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: log.h,v 1.64 2006/02/09 05:46:48 arma Exp $ */
+/* $Id: log.h,v 1.67 2006/02/18 07:18:14 weasel Exp $ */
 
 /**
  * \file log.h
@@ -11,7 +11,7 @@
  **/
 
 #ifndef __LOG_H
-#define LOG_H_ID "$Id: log.h,v 1.64 2006/02/09 05:46:48 arma Exp $"
+#define LOG_H_ID "$Id: log.h,v 1.67 2006/02/18 07:18:14 weasel Exp $"
 
 #include "../common/compat.h"
 
@@ -128,29 +128,34 @@ void _log_fn(int severity, uint32_t domain,
  * of the current function name. */
 #define log_fn(severity, domain, args...)               \
   _log_fn(severity, domain, __PRETTY_FUNCTION__, args)
-#define debug(domain, args...)                          \
+#define log_debug(domain, args...)                          \
   _log_fn(LOG_DEBUG, domain, __PRETTY_FUNCTION__, args)
-#define info(domain, args...)                           \
+#define log_info(domain, args...)                           \
   _log_fn(LOG_INFO, domain, __PRETTY_FUNCTION__, args)
-#define notice(domain, args...)                         \
+#define log_notice(domain, args...)                         \
   _log_fn(LOG_NOTICE, domain, __PRETTY_FUNCTION__, args)
-#define warn(domain, args...)                           \
+#define log_warn(domain, args...)                           \
   _log_fn(LOG_WARN, domain, __PRETTY_FUNCTION__, args)
-#define err(domain, args...)                            \
+#define log_err(domain, args...)                            \
   _log_fn(LOG_ERR, domain, __PRETTY_FUNCTION__, args)
 
 #else /* ! defined(__GNUC__) */
 
 void _log_fn(int severity, uint32_t domain, const char *format, ...);
-void debug(uint32_t domain, const char *format, ...);
-void info(uint32_t domain, const char *format, ...);
-void notice(uint32_t domain, const char *format, ...);
-void warn(uint32_t domain, const char *format, ...);
-void err(uint32_t domain, const char *format, ...);
+void _log_debug(uint32_t domain, const char *format, ...);
+void _log_info(uint32_t domain, const char *format, ...);
+void _log_notice(uint32_t domain, const char *format, ...);
+void _log_warn(uint32_t domain, const char *format, ...);
+void _log_err(uint32_t domain, const char *format, ...);
 
 #if defined(_MSC_VER) && _MSC_VER < 1300
 /* MSVC 6 and earlier don't have __FUNCTION__, or even __LINE__. */
 #define log_fn _log_fn
+#define log_debug _log_debug
+#define log_info _log_info
+#define log_notice _log_notice
+#define log_warn _log_warn
+#define log_err _log_err
 /*
 #define debug _debug
 #define info _info
@@ -166,6 +171,11 @@ extern const char *_log_fn_function_name;
  * do {...} while (0) trick to wrap this macro, since the macro can't take
  * arguments. */
 #define log_fn (_log_fn_function_name=__FUNCTION__),_log_fn
+#define log_debug (_log_fn_function_name=__FUNCTION__),_log_debug
+#define log_info (_log_fn_function_name=__FUNCTION__),_log_info
+#define log_notice (_log_fn_function_name=__FUNCTION__),_log_notice
+#define log_warn (_log_fn_function_name=__FUNCTION__),_log_warn
+#define log_err (_log_fn_function_name=__FUNCTION__),_log_err
 /*
 #define debug (_log_fn_function_name=__FUNCTION__),_debug
 #define info (_log_fn_function_name=__FUNCTION__),_info
