@@ -1,7 +1,7 @@
 /* Copyright 2003 Roger Dingledine
  * Copyright 2004-2006 Roger Dingledine, Nick Mathewson */
 /* See LICENSE for licensing information */
-/* $Id: torgzip.h,v 1.9 2006/02/09 05:46:48 arma Exp $ */
+/* $Id: torgzip.h,v 1.10 2006/02/12 23:43:17 arma Exp $ */
 
 /**
  * \file torgzip.h
@@ -10,7 +10,7 @@
 
 #ifndef __TORGZIP_H
 #define __TORGZIP_H
-#define TORGZIP_H_ID "$Id: torgzip.h,v 1.9 2006/02/09 05:46:48 arma Exp $"
+#define TORGZIP_H_ID "$Id: torgzip.h,v 1.10 2006/02/12 23:43:17 arma Exp $"
 
 typedef enum {
   GZIP_METHOD=1, ZLIB_METHOD=2, UNKNOWN_METHOD=3
@@ -24,7 +24,8 @@ int
 tor_gzip_uncompress(char **out, size_t *out_len,
                     const char *in, size_t in_len,
                     compress_method_t method,
-                    int complete_only);
+                    int complete_only,
+                    int protocol_warn_level);
 
 int is_gzip_supported(void);
 
