@@ -1,9 +1,9 @@
 /* Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2006 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: test.c,v 1.219 2006/02/09 05:46:49 arma Exp $ */
+/* $Id: test.c,v 1.221 2006/02/13 00:26:43 nickm Exp $ */
 const char test_c_id[] =
-  "$Id: test.c,v 1.219 2006/02/09 05:46:49 arma Exp $";
+  "$Id: test.c,v 1.221 2006/02/13 00:26:43 nickm Exp $";
 
 /**
  * \file test.c
@@ -835,6 +835,11 @@ test_util(void)
   test_eq(u32, 0x7f000001u);
   test_eq(u16, 0);
   tor_free(cp);
+  test_eq(0, addr_mask_get_bits(0x0u));
+  test_eq(32, addr_mask_get_bits(0xFFFFFFFFu));
+  test_eq(16, addr_mask_get_bits(0xFFFF0000u));
+  test_eq(31, addr_mask_get_bits(0xFFFFFFFEu));
+  test_eq(1, addr_mask_get_bits(0x80000000u));
 
   /* Test tor_parse_long. */
   test_eq(10L, tor_parse_long("10",10,0,100,NULL,NULL));
@@ -928,7 +933,7 @@ test_gzip(void)
     test_eq(detect_compression_method(buf2, len1), GZIP_METHOD);
 
     test_assert(!tor_gzip_uncompress(&buf3, &len2, buf2, len1,
-                                     GZIP_METHOD, 1));
+                                     GZIP_METHOD, 1, LOG_INFO));
     test_assert(buf3);
     test_streq(buf1,buf3);
 
@@ -942,7 +947,8 @@ test_gzip(void)
   test_assert(!memcmp(buf2, "\x78\xDA", 2)); /* deflate magic. */
   test_eq(detect_compression_method(buf2, len1), ZLIB_METHOD);
 
-  test_assert(!tor_gzip_uncompress(&buf3, &len2, buf2, len1, ZLIB_METHOD, 1));
+  test_assert(!tor_gzip_uncompress(&buf3, &len2, buf2, len1,
+                                   ZLIB_METHOD, 1, LOG_INFO));
   test_assert(buf3);
   test_streq(buf1,buf3);
 
@@ -951,7 +957,7 @@ test_gzip(void)
   buf2 = tor_realloc(buf2, len1*2);
   memcpy(buf2+len1, buf2, len1);
   test_assert(!tor_gzip_uncompress(&buf3, &len2, buf2, len1*2,
-                                   ZLIB_METHOD, 1));
+                                   ZLIB_METHOD, 1, LOG_INFO));
   test_eq(len2, (strlen(buf1)+1)*2);
   test_memeq(buf3,
              "AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAZAAAAAAAAAAAAAAAAAAAZ\0"
@@ -970,14 +976,15 @@ test_gzip(void)
   tor_assert(len1>16);
   /* when we allow an uncomplete string, we should succeed.*/
   tor_assert(!tor_gzip_uncompress(&buf3, &len2, buf2, len1-16,
-                                  ZLIB_METHOD, 0));
+                                  ZLIB_METHOD, 0, LOG_INFO));
   buf3[len2]='\0';
   tor_assert(len2 > 5);
   tor_assert(!strcmpstart(buf1, buf3));
 
   /* when we demand a complete string, this must fail. */
   tor_free(buf3);
-  tor_assert(tor_gzip_uncompress(&buf3, &len2, buf2, len1-16, ZLIB_METHOD, 1));
+  tor_assert(tor_gzip_uncompress(&buf3, &len2, buf2, len1-16,
+                                 ZLIB_METHOD, 1, LOG_INFO));
   tor_assert(!buf3);
 
   tor_free(buf2);
